<?php

namespace EventPortal\Domain\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Domain\Event\Form\OptionData;
use Illuminate\Support\Collection;

class UpdateOptions
{
    public function execute(Collection $options, Question $dbQuestion): void
    {
        self::deleteUnusedOptions($options, $dbQuestion);
        $options->each(static function ($option) use ($dbQuestion): void {
            $optionData = new OptionData($option, $dbQuestion);

            QuestionOption::updateOrCreate(
                ['id' => $optionData->getId()],
                $optionData->toArray()
            );
        });
    }

    private static function deleteUnusedOptions(Collection $options, Question $question): void
    {
        QuestionOption::whereNotIn('id', $options->pluck('id')->filter(null))
            ->forQuestion($question)
            ->delete();
    }
}
