<?php

namespace EventPortal\Domain\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\QuestionData;
use Illuminate\Support\Collection;

class UpdateQuestions
{
    public function execute(Collection $questions, FormStepSection $formStepSection): void
    {
        self::deleteUnusedQuestions($questions, $formStepSection);
        $questions->each(static function ($question) use ($formStepSection): void {
            $questionData = new QuestionData($question, $formStepSection);

            $dbQuestion = Question::updateOrCreate(
                ['id' => $questionData->getId()],
                $questionData->toArray()
            );

            (new UpdateValidations)->execute($questionData->validations(), $dbQuestion, $questionData->isRequired());

            (new UpdateOptions)->execute($questionData->options(), $dbQuestion);
        });
    }

    private static function deleteUnusedQuestions(Collection $questions, FormStepSection $formStepSection): void
    {
        Question::whereNotIn('id', $questions->pluck('id')->filter(null))
            ->forFormStepSection($formStepSection)
            ->delete();
    }
}
