<?php

namespace EventPortal\Domain\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\SectionData;
use Illuminate\Support\Collection;

class UpdateSections
{
    public function execute(Collection $sections, FormStep $formStep): void
    {
        self::deleteUnusedSections($sections, $formStep);
        $sections->each(static function ($section) use ($formStep): void {
            $stepData = new SectionData($section, $formStep);

            $formStepSection = FormStepSection::updateOrCreate(
                ['id' => $stepData->getId()],
                $stepData->toArray()
            );

            (new UpdateQuestions)->execute($stepData->questions(), $formStepSection);
        });
    }

    private static function deleteUnusedSections(Collection $sections, FormStep $formStep): void
    {
        FormStepSection::whereNotIn('id', $sections->pluck('id')->filter(null))
            ->forFormStep($formStep)
            ->delete();
    }
}
