<?php

namespace EventPortal\Domain\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionValidation;
use EventPortal\Domain\Event\Form\ValidationData;
use Illuminate\Support\Collection;

class UpdateValidations
{
    public function execute(Collection $validations, Question $dbQuestion, bool $isRequired = false): void
    {
        self::deleteUnusedValidations($validations, $dbQuestion);
        if (self::isRequiredValidationNeeded($isRequired, $dbQuestion)) {
            $validations->prepend([
                'rule' => 'required',
                'message' => 'This field is required',
            ]);
        }

        $validations->each(static function ($validation) use ($dbQuestion): void {
            $validationData = new ValidationData($validation, $dbQuestion);
            QuestionValidation::updateOrCreate(
                ['id' => $validationData->getId()],
                $validationData->toArray()
            );
        });
    }

    private static function deleteUnusedValidations(Collection $validations, Question $question): void
    {
        QuestionValidation::forQuestion($question)
            ->whereNotIn('id', $validations->pluck('id')->filter(null))
            ->delete();
    }

    private static function isRequiredValidationNeeded(bool $isRequired, Question $dbQuestion): bool
    {
        return $isRequired
            && QuestionValidation::forQuestion($dbQuestion)->isRequired()->exists() === false;
    }
}
