<?php

namespace EventPortal\Domain\Event\Form\Enums;

use EventPortal\Domain\Component\Date\Date;
use EventPortal\Domain\Component\Dropdown\MultiSelect;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Input\TextArea;
use EventPortal\Domain\Component\Input\TimeInput;
use EventPortal\Domain\Component\Selection\Checkbox;
use Spatie\Enum\Enum;

/**
 * @method static self SingleChoiceAnswer()
 * @method static self MultipleChoiceAnswers()
 * @method static self Dropdown()
 * @method static self SingleLineTextBox()
 * @method static self ParagraphTextBox()
 * @method static self Date()
 * @method static self Time()
 */
final class QuestionType extends Enum
{
    const MAP_VALUE = [
        'SingleChoiceAnswer' => 'Checkbox',
        'MultipleChoiceAnswers' => 'MultiSelect',
        'Dropdown' => 'Select',
        'SingleLineTextBox' => 'TextInput',
        'ParagraphTextBox' => 'TextArea',
        'Date' => 'DateInput',
        'Time' => 'TimeInput',
    ];

    /**
     * @return mixed
     */
    public function getBuilderType()
    {
        switch ($this->getValue()) {
            case self::SingleChoiceAnswer():
                return Checkbox::class;
            case self::MultipleChoiceAnswers():
                return MultiSelect::class;
            case self::Dropdown():
                return Select::class;
            case self::ParagraphTextBox():
                return TextArea::class;
            case self::Date():
                return Date::class;
            case self::Time():
                return TimeInput::class;
            default:
                return Text::class;
        }
    }

    public function getLabel(): string
    {
        switch ($this->getValue()) {
            case self::SingleChoiceAnswer():
                return 'Single choice answer';
            case self::MultipleChoiceAnswers():
                return 'Multiple choice answers';
            case self::Dropdown():
                return 'Dropdown';
            case self::ParagraphTextBox():
                return 'Paragraph text box';
            case self::Date():
                return 'Date';
            case self::Time():
                return 'Time';
            default:
                return 'Single line text box';
        }
    }
}
