<?php

namespace EventPortal\Domain\Form;

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Component\Step;
use EventPortal\Domain\Event\Form\Models\Form as FormModel;
use EventPortal\Domain\Event\Form\Models\FormStep;
use EventPortal\Domain\Event\Form\Models\FormStepSection;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Domain\Event\Form\Models\QuestionValidation;
use Illuminate\Support\Arr;

class FormRegistry
{
    /** @var array<string> */
    private $forms = [];

    public function make(string $formName): Form
    {
        if (Arr::has($this->forms, $formName)) {
            return $this->forms[$formName];
        }

        $this->forms[$formName] = new Form($formName);

        return $this->forms[$formName];
    }

    public function makeFromDatabase(FormModel $form): Form
    {
        if (Arr::has($this->forms, $form->name)) {
            return $this->forms[$form->name];
        }

        $this->forms[$form->name] = new Form($form->name);
        $this->forms[$form->name]->addSteps(static function () use ($form): array {
            return $form->steps->map(function (FormStep $step) {
                return Step::make($step->name)->fields(
                    $step->sections->map(function (FormStepSection $section) {
                        return Section::make($section->name)->fields(
                            $section->questions->map(function (Question $question) {
                                return self::makeQuestionComponent($question);
                            })->all()
                        );
                    })->all()
                );
            })->all();
        });

        return $this->forms[$form->name];
    }

    /**
     * @return mixed
     */
    private static function makeQuestionComponent(Question $question)
    {
        $component = $question->type->getBuilderType()::make($question->question);
        if ($question->options()->exists()) {
            $component->options($question->options->map(function (QuestionOption $option) {
                return Option::make($option->name);
            })->all());
        }

        if ($question->validations()->exists()) {
            $component->rules(
                $question->validations->map(function (QuestionValidation $validation) {
                    return $validation->rule;
                })->all()
            );
        }

        if ($question->isGdprSensitive()) {
            $component->gdpr();
        }

        if ($question->hasHelpText()) {
            $component->helpText($question->help_text, $question->help_position);
        }

        return $component;
    }
}
