<?php

namespace EventPortal\Tests\Unit\Agenda\Actions;

use Carbon\Carbon;
use EventPortal\Domain\Agenda\Actions\CreateDefaultAgenda;
use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class CreateDefaultAgendaTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_create_default_agenda()
    {
        Carbon::setTestNow('2020/05/28 00:00:00');

        $event = factory(Event::class)->create();

        (new CreateDefaultAgenda)->execute($event, '2020-05-28');

        $session = Session::first();

        $this
            ->assertDatabaseHas('agendas', [
                'event_id' => $event->id,
                'date' => '2020-05-28 00:00:00',
            ])
            ->assertDatabaseHas('pathways', [
                'pathwayable_id' => Agenda::first()->id,
                'pathwayable_type' => Agenda::class,
                'name' => 'Default Pathway',
                'description' => 'This is the default pathway.',
            ])
            ->assertDatabaseHas('sessions', [
                'pathway_id' => Pathway::first()->id,
                'name' => 'Example Session',
                'description' => 'Example session description',
                'location' => 'Reception',
                'starting_at' => '2020-05-28 09:00:00',
                'ending_at' => '2020-05-28 10:00:00',
            ]);
    }
}
