<?php

namespace EventPortal\Tests\Unit\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Actions\UpdateOptions;
use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Collection;

class UpdateOptionsTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_update_form_option(): void
    {
        $question = factory(Question::class)->create();
        factory(QuestionOption::class)->create(['question_id' => $question->id]);

        (new UpdateOptions)->execute($this->getUpdatedOptions(), $question);

        $option = $question->options->first();
        $this->assertEquals('Updated test uuid', $option->uuid);
        $this->assertEquals('Updated test option', $option->name);
    }

    private function getUpdatedOptions(array $override = []): Collection
    {
        return collect(array_merge([
            [
                'id' => 1,
                'value' => 'Updated test option',
                'order' => 1,
                'uuid' => 'Updated test uuid',
            ],
        ], $override));
    }

    /** @test **/
    public function can_create_new_form_option(): void
    {
        $question = factory(Question::class)->create();

        (new UpdateOptions)->execute($this->getNewOptions(), $question);

        $option = $question->options->first();
        $this->assertEquals('New test uuid', $option->uuid);
        $this->assertEquals('New test option', $option->name);
        $this->assertEquals(1, $option->order);
    }

    private function getNewOptions(array $override = []): Collection
    {
        return collect(array_merge([
            [
                'value' => 'New test option',
                'order' => 1,
                'uuid' => 'New test uuid',
            ],
        ], $override));
    }

    /** @test **/
    public function deletes_unused_form_option(): void
    {
        $question = factory(Question::class)->create();
        factory(QuestionOption::class)->create(['question_id' => $question->id]);

        (new UpdateOptions)->execute(collect([]), $question);

        $this->assertCount(0, $question->options);
    }
}
