<?php

namespace EventPortal\Tests\Unit\Handlers;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Payload;
use EventPortal\Domain\Handlers\CreateModel;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class UpdateModelTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_update_model()
    {
        $event = factory(Event::class)->create(['name' => 'Hello World']);

        $input = Payload::make(['name' => 'Goodbye World'])->withModel($event);

        app(Pipeline::class)
            ->send($input)
            ->through([new UpdateModel])
            ->thenReturn();

        $this->assertDatabaseHas('events', [
            'name' => 'Goodbye World',
        ]);
    }

    /** @test **/
    public function hydrated_model_is_added()
    {
        $event = factory(Event::class)->create(['name' => 'Hello World']);

        $input = Payload::make(['name' => 'Goodbye World'])->withModel($event);

        app(Pipeline::class)
            ->send($input)
            ->through([new UpdateModel])
            ->then(function ($input) {
                $this->assertEquals(1, $input->getModel()->id);
            });
    }
}
